@@ -14,7 +14,10 @@ except ImportError: # pragma no cover
 try: # pragma no cover
     from collections import OrderedDict
 except ImportError: # pragma no cover
-    OrderedDict = dict
+    try: 
+        from ordereddict import OrderedDict
+    except ImportError:
+        OrderedDict = dict
 
 try: # pragma no cover
     _basestring = basestring
@@ -26,7 +29,7 @@ except NameError: # pragma no cover
     _unicode = str
 
 __author__ = 'Martin Blech'
-__version__ = '0.5.0'
+__version__ = '0.5.1'
 __license__ = 'MIT'
 
 class ParsingInterrupted(Exception): pass
